#!/bin/bash

# Copyright (C) 2018  Tetras Libre <Contact@Tetras-Libre.fr>
# Author: Beniamine, David <David.Beniamine@Tetras-Libre.fr>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

exec &> >(tee -a "/var/log/startup.log")

if [ ! -f /start.sh ]
then
    #Do all startup but final exec
    execcmd=$(grep exec /startup.sh)
    sed -i -e '/^exec/d' /startup.sh
    if [ ! -z "`grep \"$USER\" /etc/shadow`" ]
    then
        echo "$USER found in shadow not changing pasword"
        # Do not reset the password
         sed -i -e '/chpasswd/d' /startup.sh
    fi
    echo -e "#!/bin/bash\n$execcmd" > /start.sh
    chmod +x /start.sh
    . /startup.sh
fi

# remove sudo from user
if [ ! -z "`groups $USER | grep sudo`" ]
then
    gpasswd -d $USER sudo
fi

# nginx pam auth
ln -sf /usr/share/nginx/modules-available/mod-http-auth-pam.conf \
    /etc/nginx/modules-enabled/50-mod-http-auth-pam.conf
sed -i -e 's|#_HTTP_PASSWORD_#||' \
    -e 's|auth_basic |auth_pam |' \
    -e 's|auth_basic_user.*|auth_pam_service_name "nginx";|' \
    -e 's|#_SSL_PORT_#||' \
    /etc/nginx/sites-enabled/default

# Add /files/ proxy
if [ -z "`grep 'location /files' /etc/nginx/sites-enabled/default`" ]
then
    sed -i \
        -e 's@_}$@_}\n\tlocation ^~ /files/ {\n\t\tproxy_pass http://files/files/;\n\t}@' \
        /etc/nginx/sites-enabled/default
fi

sed -i -e 's@location ~ /api/@location ~ ^/api/@g' /etc/nginx/sites-enabled/default

if [ -z "`grep client_max_body_size /etc/nginx/nginx.conf`" ]
then
    sed -i \
        -e 's@^\(\s*\)\(sendfile.*\)$@\1client_max_body_size 512m;\n\1\2@' \
        /etc/nginx/nginx.conf
fi

usermod -a -G shadow www-data

# starting  dbus
service dbus start

# Openssl
if [ ! -e /etc/nginx/ssl/nginx.key ]
then
    mkdir -p /etc/nginx/ssl
    echo -e "FR\n\n\n\n\n\n\n" | openssl req -x509 -nodes -days 365 -newkey rsa:2048 \
        -keyout /etc/nginx/ssl/nginx.key -out /etc/nginx/ssl/nginx.crt
fi

# Add changepassword icon
mkdir -p /home/$USER/Desktop
cat <<EOF > /home/$USER/Desktop/users.desktop
[Desktop Entry]
Type=Link
Name=Change password
Icon=config-users
URL=/usr/share/applications/users.desktop
terminal=true
EOF

cat <<EOF > /home/$USER/Desktop/help.desktop
[Desktop Entry]
Type=Application
Name=Report issue
Icon=help-browser-symbolic
Exec=/usr/bin/firefox $REPO/issues/new?issue[description]='Hello,%%0A%%0A**EXPLAIN YOUR ISSUE HERE**%%0A%%0A%%23 Technical informations %%0A%%0A %%60%%60%%60user:$USER%%60%%60%%60'
EOF

cat <<EOF > /home/$USER/.config/mimeapps.list
[Added Associations]
application/pdf=evince.desktop;

[Default Applications]
application/pdf=evince.desktop
EOF

# Add Trash bookmark
mkdir -p /home/$USER/.local/share/Trash/files
mkdir -p /home/$USER/.local/share/Trash/info
if [ -z "$(grep Trash /home/$USER/.gtk-bookmarks)" ]
then
    echo "file:///home/$USER/.local/share/Trash/files Trash" >> /home/$USER/.gtk-bookmarks
fi

# Add Empty trash action
mkdir -p /home/$USER/.local/share/file-manager/actions
cat << EOF > /home/$USER/.local/share/file-manager/actions/empty_trash.desktop
[Desktop Entry]
Type=Action
Name=Empty Trash
Icon=user-trash-full
Profiles=empty_trash;

[X-Action-Profile empty_trash]
Exec=/bin/bash -c "rm -rf /home/$USER/.local/share/Trash/files/* /home/$USER/.local/share/Trash/info/*"
MimeTypes=inode/directory;
EOF
cat << EOF > /home/$USER/Desktop/Trash.desktop
[Desktop Entry]
Type=Application
Name=Trash
Icon=user-trash
Exec=/usr/bin/pcmanfm /home/$USER/.local/share/Trash/files/
EOF


# Give user right on shared directory
chown -R 1000:1000 /home/shared
# Add rights
ln -sf /home/shared /home/$USER/Desktop/
rm /home/$USER/Desktop/home
ln -sf /home/$USER /home/$USER/Desktop/home

# logo

sed -i -e 's/^\(wallpaper_mode=\).*/\1center/' \
    -e 's/^\(wallpaper0=\).*/\1\/usr\/local\/share\/logo.png/' \
    -e 's/^\(desktop_bg=\).*/\1#cecece/' \
    /home/$USER/.config/pcmanfm/LXDE/desktop-items-0.conf

# Set LC + aliases to run stuff in virtualenv
if [ -z "`grep LC_ALL /home/$USER/.bashrc`" ]
then
cat<<EOF >> /home/$USER/.bashrc
export PATH=$PATH:/home/$USER/.local/bin
export LC_ALL=C.UTF-8
export LC_LANG=C.UTF-8
EOF
fi

chown -R 1000:1000 /home/$USER

if [ ! -e "/etc/ImageMagick-6/delegates.xml" ]
then
cat <<EOF > /etc/ImageMagick-6/delegates.xml
<delegatemap>
</delegatemap>
EOF
fi

if [ ! -e "/etc/ImageMagick-6/colors.xml" ]
then
cat <<EOF > /etc/ImageMagick-6/colors.xml
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE colormap [
<!ELEMENT colormap (color)+>
<!ELEMENT color (#PCDATA)>
<!ATTLIST color name CDATA "0">
<!ATTLIST color color CDATA "rgb(0,0,0)">
<!ATTLIST color compliance CDATA "SVG">
]>
<!--
  Associate a color name with its red, green, blue, and alpha intensities.

  A number of methods and options require a color parameter. It is often
  convenient to refer to a color by name (e.g. white) rather than by hex
  value (e.g. #fff). This file maps a color name to its equivalent red,
  green, blue, and alpha intensities (e.g. for white, red = 255, green =
  255, blue = 255, and alpha = 0).
-->
<colormap>
  <!-- <color name="none" color="rgba(0,0,0,0)" compliance="SVG, XPM"/> -->
  <!-- <color name="black" color="rgb(0,0,0)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="red" color="rgb(255,0,0)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="magenta" color="rgb(255,0,255)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="green" color="rgb(0,128,0)" compliance="SVG"/> -->
  <!-- <color name="cyan" color="rgb(0,255,255)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="blue" color="rgb(0,0,255)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="yellow" color="rgb(255,255,0)" compliance="SVG, X11, XPM"/> -->
  <!-- <color name="white" color="rgb(255,255,255)" compliance="SVG, X11"/> -->
</colormap>
EOF
fi

# Autorestart supervisor services
if [ `grep -c autorestart /etc/supervisor/conf.d/supervisord.conf` -lt 2 ]
then
    sed -i -e 's/^\(command=.*\)$/\1\nautorestart=true/' /etc/supervisor/conf.d/supervisord.conf
fi

# Logs supervisor services in supervisor stdout to let docker handle them
if [ `grep -c stdout_logfile /etc/supervisor/conf.d/supervisord.conf` -lt 2 ]
then
    sed -i -e 's@^\(command=.*\)$@\1\nstdout_logfile=/dev/fd/1\nstderr_logfile=/dev/fd/1@' /etc/supervisor/conf.d/supervisord.conf
fi

# Automatically reconnect on connection drop
sed -i -e 's/\(autoconnect=1\)/\1\&reconnect=1/' /usr/local/lib/web/frontend/static/js/app.1f2067be7db4becef715.js

if [ -f "/opt/shadow/shadow" ]
then
    echo "Copying shadow file"
    cp /opt/shadow/shadow /etc/shadow
    sync
fi

/shadow_monitor.sh &

# run final exec
exec /start.sh
